@@ -41,11 +41,10 @@ using namespace ccscript3Database;
 using namespace std;
 using namespace ost;
 
-SQLThread::SQLThread(ScriptInterp *interp, SQLDatabase *c, SQLDatabase *p, Symbol *r) :
+SQLThread::SQLThread(ScriptInterp *interp, SQLDatabase *c, Symbol *r) :
 ScriptThread(interp, 0, 64000l + 32000l * sizeof(void *))
 {
 	current = c;
-	prior = p;
 	sym = r;
 	hstmt = NULL;
 }
@@ -69,24 +68,18 @@ void SQLThread::run(void)
         char nbuf[12];
 	unsigned row = 0, len = 0;
 
-	if(prior && prior != current)
+	if(!current->isConnected())
 	{
-		prior->leave();
-		prior = NULL;
+		lock();
+		interp->setSymbol("sql.error", "sql-connect-failed");
+		release();
+		exit("sql-connect-failed");
 	}
-
-	if(!prior)
-	{
-		if(!current->enter())
-		{
-			interp->setSymbol("sql.error", "sql-connect-failed");
-			exit("sql-connect-failed");
-		}
-		interp->setSymbol("sql.database", current->getName());
-		interp->setSymbol("sql.error", "none");
-	}
-
+	lock();
+	interp->setSymbol("sql.database", current->getName());
+	interp->setSymbol("sql.error", "none");
 	interp->setSymbol("sql.rows", "0");
+	release();
 	        
 	err = SQLAllocHandle(SQL_HANDLE_STMT, current->hdbc, &hstmt);
         if(err != SQL_SUCCESS && err != SQL_SUCCESS_WITH_INFO)
@@ -94,7 +87,9 @@ void SQLThread::run(void)
 		hstmt = NULL;
                 SQLGetDiagRec(SQL_HANDLE_DBC, current->hdbc, 1,
                 	stat, &err, errmsg, sizeof(errmsg), &mlen);
+		lock();
 		interp->setSymbol("sql.error", (char *)errmsg + 4);
+		release();
                 slog.error("odbc: %s: %s", current->name, errmsg);
                 exit("sql-prep-failed");
         }
@@ -105,21 +100,29 @@ void SQLThread::run(void)
 		Thread::yield();
 		addString(buf, sizeof(buf), opt);
 	}
-	
+
+	Thread::yield();	
+
 	err = SQLExecDirect(hstmt, (SQLCHAR *)buf, SQL_NTS);
         if(err != SQL_SUCCESS && err != SQL_SUCCESS_WITH_INFO)
         {
 		strcpy((char *)errmsg, "sql.");
                 SQLGetDiagRec(SQL_HANDLE_DBC, current->hdbc, 1,
-                	stat, &err, errmsg, sizeof(errmsg), &mlen);
+                	stat, &err, errmsg, sizeof(errmsg) / sizeof(SQLCHAR), &mlen);
+		lock();
 		interp->setSymbol("sql.error", (char *)errmsg);
+		release();
                 slog.error("odbc: %s: %s", current->name, errmsg);
                 exit("sql-query-failed");
         }
 
+	Thread::yield();
+
         SQLRowCount(hstmt, &rowcnt);
         snprintf(buf, sizeof(buf), "%d", rowcnt);
+	lock();
 	interp->setNumber("sql.rows", buf);
+	release();
  
 	if(!sym)
 		exit(NULL);
@@ -130,6 +133,7 @@ void SQLThread::run(void)
 	        if(err != SQL_SUCCESS && err != SQL_SUCCESS_WITH_INFO)
                         break;
 
+		Thread::yield();
 		snprintf(nbuf, sizeof(nbuf), "%d", ++row);
                 SQLNumResultCols(hstmt, &cols);
                 if(cols < 1)
@@ -145,6 +149,7 @@ void SQLThread::run(void)
                         SQLGetData(hstmt, ++col, SQL_C_CHAR, buf + len, (SQLINTEGER)(256 - len), &rowcnt);
  			len = (unsigned)strlen(buf);
 			buf[len++] = '\'';
+			Thread::yield();
                 }
 		commit(sym, buf);
 		Thread::yield();
