@@ -83,6 +83,38 @@ Keydata(), Mutex()
         tq = NULL;
 }
 
+const char *ScriptCommand::getExternal(const char *opt)
+{
+	return NULL;
+}
+
+void ScriptCommand::errlog(const char *level, const char *msg)
+{
+}
+
+bool ScriptCommand::control(char **args)
+{
+	ScriptBinder *module;
+	ScriptImage *img;
+
+	enter();
+	module = ScriptBinder::first;
+	img = active;
+
+	while(module)
+	{
+		if(module->control(img, args))
+			break;
+		module = module->next;
+	}
+
+	leave();
+	if(module)
+		return true;
+
+	return false;
+}
+	
 Script::Method ScriptCommand::getHandler(const char *keyword)
 {
         Keyword *key;
