@@ -748,7 +748,7 @@ void ScriptInterp::attach(ScriptCommand *cmdref, ScriptImage *img, Name *scr)
 
 	enterMutex();
 	initRuntime(scr);
-	if(cmd->ripple)
+	if(fastStart)
 		image->fastBranch(this);
 	leaveMutex();
 }
