@@ -59,6 +59,7 @@
 
 namespace ost {
 
+class __EXPORT ScriptRegistry;
 class __EXPORT ScriptCommand;
 class __EXPORT ScriptImage;
 class __EXPORT ScriptInterp;
@@ -148,6 +149,7 @@ public:
 		Line *next;
 		union
 		{
+			ScriptRegistry *registry;
 			Method method;
 			Name *name;
 		}	scr;
@@ -229,6 +231,7 @@ public:
 		Package(const char *name);
 	};
 
+	static bool fastStart;
 	static bool useBigmem;
 	static unsigned fastStepping;
 	static unsigned autoStepping;
@@ -458,7 +461,7 @@ public:
 	 */
 	virtual void errlog(const char *level, const char *msg);
 
-protected:
+public:
 	/**
 	 * Test current command against a list of valid keywords.
 	 *
@@ -466,9 +469,8 @@ protected:
 	 * @param line record to examine in check routine.
 	 * @param list of =xxx keyword entries.
 	 */
-	bool useKeywords(Line *line, const char *list);
+	static bool useKeywords(Line *line, const char *list);
 
-public:
 	/**
 	 * Count non-keyword arguments.
 	 *
@@ -823,6 +825,7 @@ protected:
 	Method getHandler(const char *keyword)
 		{return cmds->getHandler(keyword);};
 
+public:
 	/**
 	 * Get memory for assoc data...
 	 *
@@ -831,7 +834,6 @@ protected:
 	 */
 	void *getMemory(size_t size);
 
-public:
 	/**
 	 * Fast branch linkback code.
 	 */
@@ -857,6 +859,13 @@ public:
 	 */
 	void addRegistration(Line *line);
 
+	/**
+	 * Get a registration record to use.
+	 *
+	 * @return registration object.
+	 */
+	ScriptRegistry *getRegistry(void);
+
 	/**
 	 * Add an advertised route in a priority slot.
 	 *
@@ -990,6 +999,14 @@ public:
 	 */
 	inline bool isRef(void)
 		{return (bool)(refcount > 0);};
+
+	/**
+	 * Get the active image from command.  Useful when compiling.
+	 *
+	 * @return ScriptImage of currently active image.
+	 */
+	inline ScriptImage *getActive(void)
+		{return cmds->getActive();};
 };
 
 /**
@@ -1482,6 +1499,22 @@ public:
 	~ScriptThread();
 };
 
+/**
+ * This class is used for registering scripts with an external
+ * registry.  Sometimes this is used as a base class for a more
+ * complete one.
+ *
+ * @author David Sugar <dyfet@ostel.com>
+ * @short Registry for script objects.
+ */
+class __EXPORT ScriptRegistry : public Script, public TimerPort
+{
+public:
+	const char *protocol;
+	timeout_t duration;
+	Name *scr;		// script being registered
+	Line *line;		// line of registry statement
+};
 
 /**
  * This class is used for DSO modules that impliment property
